@@ -6,15 +6,14 @@ use std::{
 use rusqlite::{params, Connection, Result};
 
 lazy_static! {
-    static ref CONFIG_DIR: PathBuf = {
+    static ref DB_DIR: PathBuf = {
         let config_dir = dirs::config_dir().unwrap().join("t");
 
         if !Path::new(config_dir.as_path()).exists() {
             std::fs::create_dir(config_dir.as_path()).unwrap();
         }
-        config_dir
+        config_dir.join("t.db")
     };
-    static ref DB_DIR: PathBuf = dirs::config_dir().unwrap().join("t\\t.db");
 }
 
 pub struct Database {
@@ -82,6 +81,7 @@ impl Database {
     }
     pub fn delete_tasks(&self, ids: &[usize]) {
         let ids = self.get_real_ids(ids);
+
         for id in ids {
             self.conn
                 .execute("DELETE FROM tasks WHERE rowid = ?", [id])
@@ -128,14 +128,16 @@ impl Database {
         }
     }
     pub fn get_real_ids(&self, ids: &[usize]) -> Vec<usize> {
-        let mut stmt = self.conn.prepare("SELECT rowid FROM tasks").unwrap();
-        let real_ids: Vec<usize> = stmt
-            .query_map([], |row| Ok(row.get(0).unwrap()))
-            .unwrap()
-            .flatten()
-            .collect();
+        let boards = self.get_boards();
+        let mut real_ids = Vec::new();
+        for board in boards {
+            for task in board.tasks {
+                real_ids.push(task.id);
+            }
+        }
         ids.iter()
-            .map(|id| real_ids.get(*id - 1).unwrap().clone())
+            .flat_map(|id| real_ids.get(*id - 1))
+            .cloned()
             .collect()
     }
     pub fn get_boards(&self) -> Vec<Board> {
